@@ -4,21 +4,25 @@
 #' growing library. If called without any parameters, a random quote is
 #' returned.
 #'
-#' @param ID \code{\link{character}}, qoute ID to be returned.
-#' @param author \code{\link{character}}, all quotes by specified author.
-#' @param separated \code{\link{logical}}, return result in separated form.
+#' @param ID [character] (*optional*): qoute ID to be returned.
+#'
+#' @param separated [logical] (*with default*): return result in separated form.
+#'
 #' @return Returns a character with quote and respective (false) author.
-#' @section Function version: 0.1.1
+#'
+#' @section Function version: 0.1.2
+#'
 #' @author Michael Dietze, GFZ Potsdam (Germany)
+#'
 #' @examples
 #'
 #' ## ask for an arbitrary qoute
 #' get_Quote()
 #'
+#' @md
 #' @export
 get_Quote <- function(
   ID,
-  author,
   separated = FALSE
 ) {
 
@@ -67,13 +71,10 @@ get_Quote <- function(
     )
 
   ## Check input data
-  if(missing(ID) == TRUE & missing(author) == TRUE) {
+  if(missing(ID) == TRUE) {
     ID <- sample(x = seq(from = 1,
                          to = nrow(quotes)),
                  size = 1)
-  } else if(missing(ID) == TRUE) {
-    ID <- seq(from = 1,
-              to = nrow(quotes))[quotes[,1] == author]
   }
 
   ## check for correct ID and generate qoute
