@@ -4,74 +4,81 @@
 #' RLum.Analysis S4 class object
 #'
 #' The function produces a multiple plot output. A file output is recommended
-#' (e.g., \code{\link{pdf}}).
+#' (e.g., [pdf]).
 #'
-#' \bold{curve.transformation}\cr
+#' **curve.transformation**
 #'
 #' This argument allows transforming continuous wave (CW) curves to pseudo
 #' (linear) modulated curves. For the transformation, the functions of the
 #' package are used. Currently, it is not possible to pass further arguments to
-#' the transformation functions. The argument works only for \code{ltype}
-#' \code{OSL} and \code{IRSL}.\cr
+#' the transformation functions. The argument works only for `ltype`
+#' `OSL` and `IRSL`.
 #'
 #' Please note: The curve transformation within this functions works roughly,
 #' i.e. every IRSL or OSL curve is transformed, without considerung whether it
 #' is measured with the PMT or not! However, for a fast look it might be
-#' helpful.\cr
+#' helpful.
 #'
 #'
-#' @param object \code{\linkS4class{RLum.Analysis}} (\bold{required}): S4
-#' object of class \code{RLum.Analysis}
+#' @param object [RLum.Analysis-class] (**required**):
+#' S4 object of class `RLum.Analysis`
 #'
-#' @param subset named \code{\link{list}} (optional): subsets elements for plotting. The
-#' arguments in the named \code{\link{list}} will be directly passed to the function \code{\link{get_RLum}}
-#' (e.g., \code{subset = list(curveType = "measured")})
+#' @param subset named [list] (*optional*):
+#' subsets elements for plotting. The arguments in the named [list] will be
+#' directly passed to the function [get_RLum]
+#' (e.g., `subset = list(curveType = "measured")`)
 #'
-#' @param nrows \code{\link{integer}} (optional): sets number of rows for
-#' plot output, if nothing is set the function tries to find a value.
+#' @param nrows [integer] (*optional*):
+#' sets number of rows for plot output, if nothing is set the function
+#' tries to find a value.
 #'
-#' @param ncols \code{\link{integer}} (optional): sets number of columns
-#' for plot output, if nothing is set the function tries to find a value.
+#' @param ncols [integer] (*optional*):
+#' sets number of columns for plot output, if nothing is set the function
+#' tries to find a value.
 #'
-#' @param abline \code{\link{list}} (optional): allows to add ablines to the plot. Argument are provided
-#' in a list and will be forwared to the function \code{\link{abline}}, e.g., \code{list(v = c(10, 100))}
-#' adds two vertical lines add 10 and 100 to all plots. In contrast \code{list(v = c(10), v = c(100)}
-#' adds a vertical at 10 to the first and a vertical line at 100 to the 2nd plot.
+#' @param abline [list] (*optional*):
+#' allows to add ablines to the plot. Argument are provided
+#' in a list and will be forwared to the function [abline],
+#' e.g., `list(v = c(10, 100))` adds two vertical lines add 10 and 100 to all
+#' plots. In contrast `list(v = c(10), v = c(100)` adds a vertical at 10 to
+#' the first and a vertical line at 100 to the 2nd plot.
 #'
-#' @param combine \code{\link{logical}} (with default): allows to combine all
-#' \code{\linkS4class{RLum.Data.Curve}} objects in one single plot.
+#' @param combine [logical] (*with default*):
+#' allows to combine all [RLum.Data.Curve-class] objects in one single plot.
 #'
-#' @param curve.transformation \code{\link{character}} (optional): allows
-#' transforming CW-OSL and CW-IRSL curves to pseudo-LM curves via
-#' transformation functions. Allowed values are: \code{CW2pLM}, \code{CW2pLMi},
-#' \code{CW2pHMi} and \code{CW2pPMi}. See details.
+#' @param curve.transformation [character] (*optional*):
+#' allows transforming CW-OSL and CW-IRSL curves to pseudo-LM curves via
+#' transformation functions. Allowed values are: `CW2pLM`, `CW2pLMi`,
+#' `CW2pHMi` and `CW2pPMi`. See details.
 #'
-#' @param plot.single \code{\link{logical}} (with default): global par settings are
-#' considered, normally this should end in one plot per page
+#' @param plot.single [logical] (*with default*):
+#' global par settings are considered, normally this should end in one plot per page
 #'
-#' @param \dots further arguments and graphical parameters will be passed to
-#' the \code{plot} function. Supported arguments: \code{main}, \code{mtext},
-#' \code{log}, \code{lwd}, \code{lty} \code{type}, \code{pch}, \code{col},
-#' \code{norm}, \code{xlim},\code{ylim}, \code{xlab}, \code{ylab}... and for \code{combine = TRUE}
-#' also: \code{sub}, \code{legend}, \code{legend.text}, \code{legend.pos} (typical plus 'outside'), \code{legend.col}, \code{smooth}.
-#' All arguments can be provided as \code{vector} or \code{list} to gain in full control
+#' @param ... further arguments and graphical parameters will be passed to
+#' the `plot` function.
+#'
+#' Supported arguments: `main`, `mtext`, `log`, `lwd`, `lty` `type`, `pch`, `col`,
+#' `norm`, `xlim`,`ylim`, `xlab`, `ylab`...
+#'
+#' and for `combine = TRUE` also: `sub`, `legend`, `legend.text`, `legend.pos`
+#' (typical plus 'outside'), `legend.col`, `smooth`.
+#'
+#' All arguments can be provided as `vector` or `list` to gain in full control
 #' of all plot settings.
 #'
 #' @return Returns multiple plots.
 #'
-#' @note Not all arguments available for \code{\link{plot}} will be passed!
-#' Only plotting of \code{RLum.Data.Curve} and \code{RLum.Data.Spectrum}
-#' objects are currently supported.\cr
+#' @note
+#' Not all arguments available for [plot] will be passed and they partly do not behave in the
+#' way you might expect them to work. This function was designed to serve as an overview
+#' plot, if you want to have more control, extract the objects and plot them individually.
 #'
-#' @section Function version: 0.3.8
+#' @section Function version: 0.3.11
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
-#' (France)
+#' @author
+#' Sebastian Kreutzer, IRAMAT-CRP2A, Université Bordeaux Montaigne (France)
 #'
-#' @seealso \code{\link{plot}}, \code{\link{plot_RLum}},
-#' \code{\link{plot_RLum.Data.Curve}}
-#'
-#' @references #
+#' @seealso [plot], [plot_RLum], [plot_RLum.Data.Curve]
 #'
 #' @keywords aplot
 #'
@@ -103,6 +110,7 @@
 #' abline = list(v = c(110))
 #' )
 #'
+#' @md
 #' @export
 plot_RLum.Analysis <- function(
   object,
@@ -149,7 +157,7 @@ plot_RLum.Analysis <- function(
     xlim = NULL,
     ylim = NULL,
     pch = 1,
-    col = "black",
+    col = "auto",
     norm = FALSE,
     sub = NULL,
     cex = 1,
@@ -332,9 +340,11 @@ plot_RLum.Analysis <- function(
         if (!is.null(plot.settings$xlim)) {
           xlim.set <- plot.settings$xlim[[i]]
           if (plot.settings$xlim[[i]][1] < min(temp[[i]]@data[,1])) {
+            warning(paste0("[plot_RLum.Analysis()] min('xlim') < x-value range for curve #",i,"; reset to minimum."), call. = FALSE)
             xlim.set[1] <- min(temp[[i]]@data[,1])
           }
           if (plot.settings$xlim[[i]][2] > max(temp[[i]]@data[,1])) {
+            warning(paste0("[plot_RLum.Analysis()] max('xlim') > x-value range for curve #",i,"; reset to maximum."), call. = FALSE)
             xlim.set[2] <- max(temp[[i]]@data[,1])
           }
 
@@ -345,11 +355,13 @@ plot_RLum.Analysis <- function(
 
         ##ylim
         if (!is.null(plot.settings$ylim)) {
-          ylim.set <- plot.settings$ylim
+          ylim.set <- plot.settings$ylim[[i]]
           if (plot.settings$ylim[[i]][1] < min(temp[[i]]@data[,2])) {
+            warning(paste0("[plot_RLum.Analysis()] min('ylim') < y-value range for curve #",i,"; reset to minimum."), call. = FALSE)
             ylim.set[1] <- min(temp[[i]]@data[,2])
           }
           if (plot.settings$ylim[[i]][2] > max(temp[[i]]@data[,2])) {
+            warning(paste0("[plot_RLum.Analysis()] max('ylim') > y-value range for curve #",i,"; reset to maximum."), call. = FALSE)
             ylim.set[2] <- max(temp[[i]]@data[,2])
           }
 
@@ -359,8 +371,9 @@ plot_RLum.Analysis <- function(
         }
 
         ##col
-        if (unique(plot.settings$col) != "black") {
+        if (unique(plot.settings$col) != "auto") {
           col <- plot.settings$col[i]
+
         } else{
           if (grepl("IRSL", temp[[i]]@recordType)) {
             col <- "red"
@@ -369,7 +382,7 @@ plot_RLum.Analysis <- function(
               col <- "blue"
             } else
             {
-              col <- plot.settings$col[[i]]
+              col <- "black"
             }
         }
 
@@ -455,7 +468,8 @@ plot_RLum.Analysis <- function(
 
     sapply(1:length(object.list), function(x){
       if(is(object.list[[x]])[1] != "RLum.Data.Curve"){
-        stop("[plot_RLum.Analysis()] Using 'combine' is limited to 'RLum.Data.Curve' objects.")
+        stop("[plot_RLum.Analysis()] Using 'combine' is limited to 'RLum.Data.Curve' objects.",
+             call. = FALSE)
 
       }
 
@@ -621,11 +635,12 @@ plot_RLum.Analysis <- function(
         ylim[which(ylim == 0)] <- 1
 
       ##col (again)
-      col <- if(length(plot.settings$col[[k]]) > 1 || plot.settings$col[[k]][1] != "black"){
+      col <- if(length(plot.settings$col[[k]]) > 1 || plot.settings$col[[k]][1] != "auto"){
         plot.settings$col[[k]]
 
       }else{
         col <- get("col", pos = .LuminescenceEnv)
+
       }
 
       ##if length of provided colours is < the number of objects, just one colour is supported
